summaryrefslogtreecommitdiff
path: root/sw/inc/format.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'sw/inc/format.hxx')
-rw-r--r--sw/inc/format.hxx130
1 files changed, 65 insertions, 65 deletions
diff --git a/sw/inc/format.hxx b/sw/inc/format.hxx
index 63bb3bb13472..11ed94319e81 100644
--- a/sw/inc/format.hxx
+++ b/sw/inc/format.hxx
@@ -41,39 +41,39 @@ namespace drawinglayer { namespace attribute {
}}
/// Base class for various Writer styles.
-class SW_DLLPUBLIC SwFmt : public SwModify
+class SW_DLLPUBLIC SwFormat : public SwModify
{
- OUString m_aFmtName;
+ OUString m_aFormatName;
SwAttrSet m_aSet;
sal_uInt16 m_nWhichId;
- sal_uInt16 m_nPoolFmtId; /**< Id for "automatically" created formats.
+ sal_uInt16 m_nPoolFormatId; /**< Id for "automatically" created formats.
(is not hard attribution!!!) */
sal_uInt16 m_nPoolHelpId; ///< HelpId for this Pool-style.
sal_uInt8 m_nPoolHlpFileId; ///< FilePos to Doc to these style helps.
bool m_bWritten : 1; ///< TRUE: already written.
- bool m_bAutoFmt : 1; /**< FALSE: it is a template.
+ bool m_bAutoFormat : 1; /**< FALSE: it is a template.
default is true! */
- bool m_bFmtInDTOR : 1; /**< TRUE: Format becomes deleted. In order to be able
- to recognize this in FmtChg-message!! */
- bool m_bAutoUpdateFmt : 1;/**< TRUE: Set attributes of a whole paragraph
+ bool m_bFormatInDTOR : 1; /**< TRUE: Format becomes deleted. In order to be able
+ to recognize this in FormatChg-message!! */
+ bool m_bAutoUpdateFormat : 1;/**< TRUE: Set attributes of a whole paragraph
at format (UI-side!). */
bool m_bHidden : 1;
std::shared_ptr<SfxGrabBagItem> m_pGrabBagItem; ///< Style InteropGrabBag.
protected:
- SwFmt( SwAttrPool& rPool, const sal_Char* pFmtNm,
- const sal_uInt16* pWhichRanges, SwFmt *pDrvdFrm, sal_uInt16 nFmtWhich );
- SwFmt( SwAttrPool& rPool, const OUString &rFmtNm, const sal_uInt16* pWhichRanges,
- SwFmt *pDrvdFrm, sal_uInt16 nFmtWhich );
- SwFmt( const SwFmt& rFmt );
+ SwFormat( SwAttrPool& rPool, const sal_Char* pFormatNm,
+ const sal_uInt16* pWhichRanges, SwFormat *pDrvdFrm, sal_uInt16 nFormatWhich );
+ SwFormat( SwAttrPool& rPool, const OUString &rFormatNm, const sal_uInt16* pWhichRanges,
+ SwFormat *pDrvdFrm, sal_uInt16 nFormatWhich );
+ SwFormat( const SwFormat& rFormat );
virtual void Modify( const SfxPoolItem* pOld, const SfxPoolItem* pNewValue ) SAL_OVERRIDE;
public:
TYPEINFO_OVERRIDE(); ///< Already in base class Client.
- virtual ~SwFmt();
- SwFmt &operator=(const SwFmt&);
+ virtual ~SwFormat();
+ SwFormat &operator=(const SwFormat&);
/// for Querying of Writer-functions.
sal_uInt16 Which() const { return m_nWhichId; }
@@ -82,36 +82,36 @@ public:
virtual bool GetInfo( SfxPoolItem& ) const SAL_OVERRIDE;
/// Copy attributes even among documents.
- void CopyAttrs( const SwFmt&, bool bReplace=true );
+ void CopyAttrs( const SwFormat&, bool bReplace=true );
- /// Delete all attributes that are not in rFmt.
+ /// Delete all attributes that are not in rFormat.
void DelDiffs( const SfxItemSet& rSet );
- void DelDiffs( const SwFmt& rFmt ) { DelDiffs( rFmt.GetAttrSet() ); }
+ void DelDiffs( const SwFormat& rFormat ) { DelDiffs( rFormat.GetAttrSet() ); }
/// 0 is Default.
- bool SetDerivedFrom(SwFmt *pDerivedFrom = 0);
+ bool SetDerivedFrom(SwFormat *pDerivedFrom = 0);
/// If bInParents is FALSE, search only in this format for attribute.
//UUUUinline
- const SfxPoolItem& GetFmtAttr( sal_uInt16 nWhich,
+ const SfxPoolItem& GetFormatAttr( sal_uInt16 nWhich,
bool bInParents = true ) const;
//UUUUinline
SfxItemState GetItemState( sal_uInt16 nWhich, bool bSrchInParent = true,
const SfxPoolItem **ppItem = 0 ) const;
SfxItemState GetBackgroundState(SvxBrushItem &rItem,
bool bSrchInParent = true) const;
- virtual bool SetFmtAttr( const SfxPoolItem& rAttr );
- virtual bool SetFmtAttr( const SfxItemSet& rSet );
- virtual bool ResetFmtAttr( sal_uInt16 nWhich1, sal_uInt16 nWhich2 = 0 );
+ virtual bool SetFormatAttr( const SfxPoolItem& rAttr );
+ virtual bool SetFormatAttr( const SfxItemSet& rSet );
+ virtual bool ResetFormatAttr( sal_uInt16 nWhich1, sal_uInt16 nWhich2 = 0 );
/** Takes all hints from Delta-Array,
@return count of deleted hints. */
- virtual sal_uInt16 ResetAllFmtAttr();
+ virtual sal_uInt16 ResetAllFormatAttr();
- inline SwFmt* DerivedFrom() const { return const_cast<SwFmt*>(static_cast<const SwFmt*>(GetRegisteredIn())); }
+ inline SwFormat* DerivedFrom() const { return const_cast<SwFormat*>(static_cast<const SwFormat*>(GetRegisteredIn())); }
inline bool IsDefault() const { return DerivedFrom() == 0; }
- inline OUString GetName() const { return m_aFmtName; }
+ inline OUString GetName() const { return m_aFormatName; }
void SetName( const OUString& rNewName, bool bBroadcast=false );
inline void SetName( const sal_Char* pNewName,
bool bBroadcast=false);
@@ -145,8 +145,8 @@ public:
IDocumentChartDataProviderAccess* getIDocumentChartDataProviderAccess();
/// Get and set Pool style IDs.
- sal_uInt16 GetPoolFmtId() const { return m_nPoolFmtId; }
- void SetPoolFmtId( sal_uInt16 nId ) { m_nPoolFmtId = nId; }
+ sal_uInt16 GetPoolFormatId() const { return m_nPoolFormatId; }
+ void SetPoolFormatId( sal_uInt16 nId ) { m_nPoolFormatId = nId; }
/// Get and set Help-IDs for document templates.
sal_uInt16 GetPoolHelpId() const { return m_nPoolHelpId; }
@@ -162,9 +162,9 @@ public:
/// Format-ID for reading/writing:
void ResetWritten() { m_bWritten = false; }
- /// Query / set AutoFmt-flag.
- bool IsAuto() const { return m_bAutoFmt; }
- void SetAuto( bool bNew = false ) { m_bAutoFmt = bNew; }
+ /// Query / set AutoFormat-flag.
+ bool IsAuto() const { return m_bAutoFormat; }
+ void SetAuto( bool bNew = false ) { m_bAutoFormat = bNew; }
bool IsHidden() const { return m_bHidden; }
void SetHidden( bool bValue = false ) { m_bHidden = bValue; }
@@ -172,11 +172,11 @@ public:
void GetGrabBagItem(com::sun::star::uno::Any& rVal) const;
void SetGrabBagItem(const com::sun::star::uno::Any& rVal);
- /// Query / set bAutoUpdateFmt-flag.
- bool IsAutoUpdateFmt() const { return m_bAutoUpdateFmt; }
- void SetAutoUpdateFmt( bool bNew = true ) { m_bAutoUpdateFmt = bNew; }
+ /// Query / set bAutoUpdateFormat-flag.
+ bool IsAutoUpdateFormat() const { return m_bAutoUpdateFormat; }
+ void SetAutoUpdateFormat( bool bNew = true ) { m_bAutoUpdateFormat = bNew; }
- bool IsFmtInDTOR() const { return m_bFmtInDTOR; }
+ bool IsFormatInDTOR() const { return m_bFormatInDTOR; }
/** GetMethods: Bool indicates whether to search only in Set (FALSE)
or also in Parents.
@@ -227,48 +227,48 @@ public:
inline const SvxShadowItem &GetCharShadow( bool = true ) const;
/// Frame-attributes - implemented in frmatr.hxx.
- inline const SwFmtFillOrder &GetFillOrder( bool = true ) const;
- inline const SwFmtFrmSize &GetFrmSize( bool = true ) const;
- inline const SwFmtHeader &GetHeader( bool = true ) const;
- inline const SwFmtFooter &GetFooter( bool = true ) const;
- inline const SwFmtSurround &GetSurround( bool = true ) const;
- inline const SwFmtHoriOrient &GetHoriOrient( bool = true ) const;
- inline const SwFmtAnchor &GetAnchor( bool = true ) const;
- inline const SwFmtCol &GetCol( bool = true ) const;
+ inline const SwFormatFillOrder &GetFillOrder( bool = true ) const;
+ inline const SwFormatFrmSize &GetFrmSize( bool = true ) const;
+ inline const SwFormatHeader &GetHeader( bool = true ) const;
+ inline const SwFormatFooter &GetFooter( bool = true ) const;
+ inline const SwFormatSurround &GetSurround( bool = true ) const;
+ inline const SwFormatHoriOrient &GetHoriOrient( bool = true ) const;
+ inline const SwFormatAnchor &GetAnchor( bool = true ) const;
+ inline const SwFormatCol &GetCol( bool = true ) const;
inline const SvxPaperBinItem &GetPaperBin( bool = true ) const;
inline const SvxLRSpaceItem &GetLRSpace( bool = true ) const;
inline const SvxULSpaceItem &GetULSpace( bool = true ) const;
- inline const SwFmtCntnt &GetCntnt( bool = true ) const;
+ inline const SwFormatContent &GetContent( bool = true ) const;
inline const SvxPrintItem &GetPrint( bool = true ) const;
inline const SvxOpaqueItem &GetOpaque( bool = true ) const;
inline const SvxProtectItem &GetProtect( bool = true ) const;
- inline const SwFmtVertOrient &GetVertOrient( bool = true ) const;
+ inline const SwFormatVertOrient &GetVertOrient( bool = true ) const;
inline const SvxBoxItem &GetBox( bool = true ) const;
- inline const SvxFmtKeepItem &GetKeep( bool = true ) const;
+ inline const SvxFormatKeepItem &GetKeep( bool = true ) const;
//UUUU Create SvxBrushItem for Background fill (partially for backwards compatibility)
SvxBrushItem makeBackgroundBrushItem( bool = true ) const;
inline const SvxShadowItem &GetShadow( bool = true ) const;
- inline const SwFmtPageDesc &GetPageDesc( bool = true ) const;
- inline const SvxFmtBreakItem &GetBreak( bool = true ) const;
+ inline const SwFormatPageDesc &GetPageDesc( bool = true ) const;
+ inline const SvxFormatBreakItem &GetBreak( bool = true ) const;
inline const SvxMacroItem &GetMacro( bool = true ) const;
- inline const SwFmtURL &GetURL( bool = true ) const;
- inline const SwFmtEditInReadonly &GetEditInReadonly( bool = true ) const;
- inline const SwFmtLayoutSplit &GetLayoutSplit( bool = true ) const;
- inline const SwFmtRowSplit &GetRowSplit( bool = true ) const;
- inline const SwFmtChain &GetChain( bool = true ) const;
- inline const SwFmtLineNumber &GetLineNumber( bool = true ) const;
- inline const SwFmtFtnAtTxtEnd &GetFtnAtTxtEnd( bool = true ) const;
- inline const SwFmtEndAtTxtEnd &GetEndAtTxtEnd( bool = true ) const;
- inline const SwFmtNoBalancedColumns &GetBalancedColumns( bool = true ) const;
+ inline const SwFormatURL &GetURL( bool = true ) const;
+ inline const SwFormatEditInReadonly &GetEditInReadonly( bool = true ) const;
+ inline const SwFormatLayoutSplit &GetLayoutSplit( bool = true ) const;
+ inline const SwFormatRowSplit &GetRowSplit( bool = true ) const;
+ inline const SwFormatChain &GetChain( bool = true ) const;
+ inline const SwFormatLineNumber &GetLineNumber( bool = true ) const;
+ inline const SwFormatFootnoteAtTextEnd &GetFootnoteAtTextEnd( bool = true ) const;
+ inline const SwFormatEndAtTextEnd &GetEndAtTextEnd( bool = true ) const;
+ inline const SwFormatNoBalancedColumns &GetBalancedColumns( bool = true ) const;
inline const SvxFrameDirectionItem &GetFrmDir( bool = true ) const;
inline const SwTextGridItem &GetTextGrid( bool = true ) const;
inline const SwHeaderAndFooterEatSpacingItem &GetHeaderAndFooterEatSpacing( bool = true ) const;
// #i18732#
- inline const SwFmtFollowTextFlow &GetFollowTextFlow(bool = true) const;
+ inline const SwFormatFollowTextFlow &GetFollowTextFlow(bool = true) const;
// #i28701#
- inline const SwFmtWrapInfluenceOnObjPos& GetWrapInfluenceOnObjPos(bool = true) const;
+ inline const SwFormatWrapInfluenceOnObjPos& GetWrapInfluenceOnObjPos(bool = true) const;
inline const SdrTextVertAdjustItem& GetTextVertAdjust(bool = true) const;
/// Graphics-attributes - implemented in grfatr.hxx
@@ -288,14 +288,14 @@ public:
/// Paragraph-attributes - implemented in paratr.hxx.
inline const SvxLineSpacingItem &GetLineSpacing( bool = true ) const;
inline const SvxAdjustItem &GetAdjust( bool = true ) const;
- inline const SvxFmtSplitItem &GetSplit( bool = true ) const;
+ inline const SvxFormatSplitItem &GetSplit( bool = true ) const;
inline const SwRegisterItem &GetRegister( bool = true ) const;
inline const SwNumRuleItem &GetNumRule( bool = true ) const;
inline const SvxWidowsItem &GetWidows( bool = true ) const;
inline const SvxOrphansItem &GetOrphans( bool = true ) const;
inline const SvxTabStopItem &GetTabStops( bool = true ) const;
inline const SvxHyphenZoneItem &GetHyphenZone( bool = true ) const;
- inline const SwFmtDrop &GetDrop( bool = true ) const;
+ inline const SwFormatDrop &GetDrop( bool = true ) const;
inline const SvxScriptSpaceItem &GetScriptSpace(bool = true) const;
inline const SvxHangingPunctuationItem &GetHangingPunctuation(bool = true) const;
inline const SvxForbiddenRuleItem &GetForbiddenRule(bool = true) const;
@@ -304,11 +304,11 @@ public:
inline const SwParaConnectBorderItem &GetParaConnectBorder(bool = true ) const;
/// TableBox attributes - implemented in cellatr.hxx.
- inline const SwTblBoxNumFormat &GetTblBoxNumFmt( bool = true ) const;
- inline const SwTblBoxFormula &GetTblBoxFormula( bool = true ) const;
- inline const SwTblBoxValue &GetTblBoxValue( bool = true ) const;
+ inline const SwTableBoxNumFormat &GetTableBoxNumFormat( bool = true ) const;
+ inline const SwTableBoxFormula &GetTableBoxFormula( bool = true ) const;
+ inline const SwTableBoxValue &GetTableBoxValue( bool = true ) const;
- /** SwFmt::IsBackgroundTransparent
+ /** SwFormat::IsBackgroundTransparent
Virtual method to determine, if background of format is transparent.
Default implementation returns false. Thus, subclasses have to override
@@ -325,7 +325,7 @@ public:
virtual bool supportsFullDrawingLayerFillAttributeSet() const;
};
-inline void SwFmt::SetName( const sal_Char* pNewName,
+inline void SwFormat::SetName( const sal_Char* pNewName,
bool bBroadcast )
{
SetName(OUString::createFromAscii(pNewName), bBroadcast);